@@ -51,7 +51,7 @@
 #undef Status
 #endif
 
-static Lum::AppInfo info;
+static Lum::Def::AppInfo info;
 
 class Settings : public Lum::Dlg::ActionDialog
 {
